package de.intevation.gnv.state.cache;
/**
 * This Class is a Container which carries the
 * databasequery which belongs to an state.
 * It is also possible to look up if the query contains a specific
 * TableName.
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class QueryObject {

    /**
     * The Id of the State the Query belongs to
     */
    private String stateId = null;

    /**
     * The Query which belongs to the State
     */
    private String query = null;

    /**
     * Constructor
     * @param stateId the Id of the State the Query belongs to
     * @param query the Query which belongs to the State
     */
    public QueryObject(String stateId, String query) {
        this.stateId = stateId;
        this.query = query.toUpperCase();
    }

    /**
     * Returns the StateId
     * @return the Stateid
     */
    public String getStateId() {
        return stateId;
    }

    /**
     * Returns the Querystring
     * @return the QueryString
     */
    public String getQuery() {
        return query;
    }

    /**
     * Returns true if the given Name of the Table is Contained in the Query
     * @param tableName the Name of the Table
     * @return true if the Name of the Table is contained in the Query
     */
    public boolean queryContainsTableName(String tableName){
        return this.query.contains(tableName);
    }
}
